==> open-xchange-documents-backend_7.8.4.orig.tar.bz2: open-xchange-documents-backend-7.8.4/com.openexchange.office.rest/src/com/openexchange/office/rest/CopyDocumentAction.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.office.rest;

import org.json.JSONException;
import org.json.JSONObject;

import com.openexchange.ajax.requesthandler.AJAXRequestData;
import com.openexchange.ajax.requesthandler.AJAXRequestResult;
import com.openexchange.documentation.RequestMethod;
import com.openexchange.documentation.annotations.Action;
import com.openexchange.documentation.annotations.Parameter;
import com.openexchange.exception.OXException;
import com.openexchange.office.tools.rest.RequestDataHelper;
import com.openexchange.server.ServiceLookup;
import com.openexchange.tools.servlet.AjaxExceptionCodes;
import com.openexchange.tools.session.ServerSession;

public class CopyDocumentAction extends DocumentRESTAction {

    /**
     * {@link CopyDocumentAction}
     *
     * @author <a href="mailto:carsten.driesner@open-xchange.com">Carsten Driesner</a>
     */

    @Action(method = RequestMethod.GET, name = "copydocument", description = "Request to create a copy of the selection of a calc document for the clipboard.", parameters = {
        @Parameter(name = "session", description = "A session ID previously obtained from the login module."),
        @Parameter(name = "file_id", description = "Object ID of the requested infoitem."),
        @Parameter(name = "target_filename", optional=true, description = "If present the new filename of the requested filestore item to be set."),
        @Parameter(name = "asTemplate", optional=true, description = "If present specifies that the file should be stored as template."),
        @Parameter(name = "target_folder_id", optional=true, description = "If present the folder ID where to write the requested infoitem, otherwise the folder of the source is used or if not possible the"),
        @Parameter(name = "uid", description = "The unique id of the client application.")
    }, responseDescription = "Response with timestamp: A JSON object containing the new data of the copied file or error information.")

    /**
     * Initializes a new {@link CopyDocumentAction}.
     * @param services
     */
    public CopyDocumentAction(ServiceLookup servicesDEPRECATED) {
        super(null);
    }

    /* (non-Javadoc)
     * @see com.openexchange.ajax.requesthandler.AJAXActionService#perform(com.openexchange.ajax.requesthandler.AJAXRequestData, com.openexchange.tools.session.ServerSession)
     */
    @Override
    public AJAXRequestResult perform(AJAXRequestData request, ServerSession session) throws OXException {
        final JSONObject requestData = new JSONObject();
        final RequestDataHelper helper = new RequestDataHelper(request);

        RequestDataHelper.mapOfficeParamsToNormalParam(request, session, null, requestData);
        
        try {
            requestData.put("fileName", helper.getParameter("target_filename"));
            requestData.put("asTemplate", helper.getParameter("asTemplate"));
            requestData.put("targetFolder", helper.getParameter("target_folder_id"));
        } catch (JSONException e) {
            throw AjaxExceptionCodes.UNEXPECTED_ERROR.create(e, e.getMessage());
        }

        final JSONObject result = sendConnectionMessageSynchronously(request, session, "copyDocument", "document", requestData);
        return getAjaxRequestResult(result);
    }
}

==> open-xchange-documents-backend_7.10.0.orig.tar.bz2: open-xchange-documents-backend-7.10.0/com.openexchange.office.rest/src/com/openexchange/office/rest/CopyDocumentAction.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.office.rest;

import org.json.JSONException;
import org.json.JSONObject;

import com.openexchange.ajax.requesthandler.AJAXRequestData;
import com.openexchange.ajax.requesthandler.AJAXRequestResult;
import com.openexchange.exception.OXException;
import com.openexchange.office.tools.rest.RequestDataHelper;
import com.openexchange.server.ServiceLookup;
import com.openexchange.tools.servlet.AjaxExceptionCodes;
import com.openexchange.tools.session.ServerSession;

public class CopyDocumentAction extends DocumentRESTAction {

    /**
     * {@link CopyDocumentAction}
     *
     * @author <a href="mailto:carsten.driesner@open-xchange.com">Carsten Driesner</a>
     */

    // @Action(method = RequestMethod.GET, name = "copydocument", description = "Request to create a copy of the selection of a calc document for the clipboard.", parameters = {
    //    @Parameter(name = "session", description = "A session ID previously obtained from the login module."),
    //    @Parameter(name = "file_id", description = "Object ID of the requested infoitem."),
    //    @Parameter(name = "target_filename", optional=true, description = "If present the new filename of the requested filestore item to be set."),
    //    @Parameter(name = "asTemplate", optional=true, description = "If present specifies that the file should be stored as template."),
    //    @Parameter(name = "target_folder_id", optional=true, description = "If present the folder ID where to write the requested infoitem, otherwise the folder of the source is used or if not possible the"),
    //    @Parameter(name = "uid", description = "The unique id of the client application.")
    // }, responseDescription = "Response with timestamp: A JSON object containing the new data of the copied file or error information.")

    /**
     * Initializes a new {@link CopyDocumentAction}.
     * @param services
     */
    public CopyDocumentAction(ServiceLookup servicesDEPRECATED) {
        super(null);
    }

    /* (non-Javadoc)
     * @see com.openexchange.ajax.requesthandler.AJAXActionService#perform(com.openexchange.ajax.requesthandler.AJAXRequestData, com.openexchange.tools.session.ServerSession)
     */
    @Override
    public AJAXRequestResult perform(AJAXRequestData request, ServerSession session) throws OXException {
        final JSONObject requestData = new JSONObject();
        final RequestDataHelper helper = new RequestDataHelper(request);

        RequestDataHelper.mapOfficeParamsToNormalParam(request, session, null, requestData);

        try {
            requestData.put("fileName", helper.getParameter("target_filename"));
            requestData.put("asTemplate", helper.getParameter("asTemplate"));
            requestData.put("targetFolder", helper.getParameter("target_folder_id"));
        } catch (JSONException e) {
            throw AjaxExceptionCodes.UNEXPECTED_ERROR.create(e, e.getMessage());
        }

        final JSONObject result = sendConnectionMessageSynchronously(request, session, "copyDocument", "document", requestData);
        return getAjaxRequestResult(result);
    }
}
